import {StonithAgentListAgents} from "dev/types";

export const ok: StonithAgentListAgents = [
  {
    name: "stonith:fence_amt_ws",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_apc",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_apc_snmp",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_bladecenter",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_brocade",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_cisco_mds",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_cisco_ucs",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_compute",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_drac5",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_eaton_snmp",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_emerson",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_eps",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_evacuate",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_heuristics_ping",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_hpblade",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_ibmblade",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_idrac",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_ifmib",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_ilo",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_ilo2",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_ilo3",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_ilo3_ssh",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_ilo4",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_ilo4_ssh",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_ilo5",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_ilo5_ssh",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_ilo_moonshot",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_ilo_mp",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_ilo_ssh",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_imm",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_intelmodular",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_ipdu",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_ipmilan",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_kdump",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_mpath",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_redfish",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_rhevm",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_rsa",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_rsb",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_sbd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_scsi",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_virt",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_vmware_rest",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_vmware_soap",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_wti",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "stonith:fence_xvm",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
];
