import {ResourceAgentListAgents} from "dev/types";

export const ok: ResourceAgentListAgents = [
  {
    name: "ocf:booth:geostore",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:apache",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:aws-vpc-move-ip",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:aws-vpc-route53",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:awseip",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:awsvip",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:azure-events",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:azure-lb",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:conntrackd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:CTDB",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:db2",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:Delay",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:dhcpd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:docker",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:Dummy",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:ethmonitor",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:exportfs",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:Filesystem",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:galera",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:garbd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:iface-vlan",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:IPaddr",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:IPaddr2",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:IPsrcaddr",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:iSCSILogicalUnit",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:iSCSITarget",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:LVM-activate",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:lvmlockd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:MailTo",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:mysql",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:nagios",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:named",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:nfsnotify",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:nfsserver",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:nginx",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:NodeUtilization",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:oraasm",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:oracle",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:oralsnr",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:pgsql",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:podman",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:portblock",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:postfix",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:rabbitmq-cluster",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:redis",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:Route",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:rsyncd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:SendArp",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:slapd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:Squid",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:sybaseASE",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:symlink",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:tomcat",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:vdo-vol",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:VirtualDomain",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:heartbeat:Xinetd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:openstack:nova-compute-wait",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:openstack:NovaEvacuate",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:pacemaker:attribute",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:pacemaker:booth-site",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:pacemaker:ClusterMon",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:pacemaker:controld",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:pacemaker:Dummy",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:pacemaker:HealthCPU",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:pacemaker:HealthIOWait",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:pacemaker:HealthSMART",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:pacemaker:ifspeed",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:pacemaker:ping",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:pacemaker:pingd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:pacemaker:remote",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:pacemaker:Stateful",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:pacemaker:SysInfo",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "ocf:pacemaker:SystemHealth",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:-.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:arp-ethers",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:auditd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:auth-rpcgss-module",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:autovt@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:blk-availability",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:boot.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:booth-arbitrator",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:booth@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:chrony-dnssrv@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:chrony-dnssrv@.timer",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:chrony-wait",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:chronyd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:console-getty",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:container-getty@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:corosync",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:corosync-notifyd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:cpupower",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:crm_mon",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:crond",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dbus",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dbus-org.freedesktop.hostname1",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dbus-org.freedesktop.locale1",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dbus-org.freedesktop.login1",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dbus-org.freedesktop.nm-dispatcher",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dbus-org.freedesktop.portable1",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dbus-org.freedesktop.timedate1",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dbus.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:debug-shell",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dev-hugepages.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dev-mqueue.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dm-event",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dm-event.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dnf-makecache",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dnf-makecache.timer",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dracut-cmdline",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dracut-initqueue",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dracut-mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dracut-pre-mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dracut-pre-pivot",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dracut-pre-trigger",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dracut-pre-udev",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:dracut-shutdown",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:ebtables",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:emergency",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:firewalld",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:fstrim",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:fstrim.timer",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:getty@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:grub-boot-indeterminate",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:gssproxy",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:halt-local",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:import-state",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:initrd-cleanup",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:initrd-parse-etc",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:initrd-switch-root",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:initrd-udevadm-cleanup-db",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:iprdump",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:iprinit",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:iprupdate",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:irqbalance",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:kdump",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:kmod-static-nodes",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:ldconfig",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:loadmodules",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:lvm2-lvmpolld",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:lvm2-lvmpolld.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:lvm2-monitor",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:lvm2-pvscan@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:man-db-cache-update",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:messagebus",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:microcode",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:multipathd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:multipathd.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:NetworkManager",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:NetworkManager-dispatcher",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:NetworkManager-wait-online",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:nfs-blkmap",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:nfs-convert",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:nfs-idmapd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:nfs-mountd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:nfs-server",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:nfs-utils",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:nfsdcld",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:nftables",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:nis-domainname",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:oddjobd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:pacemaker",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:pcsd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:pcsd-ruby",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:plymouth-halt",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:plymouth-kexec",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:plymouth-poweroff",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:plymouth-quit",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:plymouth-quit-wait",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:plymouth-read-write",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:plymouth-reboot",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:plymouth-start",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:plymouth-switch-root",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:plymouth-switch-root-initramfs",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:polkit",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:proc-fs-nfsd.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:proc-sys-fs-binfmt_misc.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:qemu-guest-agent",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:quotaon",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:rc-local",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:rdisc",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:rescue",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:rhsm",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:rhsm-facts",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:rhsmcertd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:rngd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:rngd-wake-threshold",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:rpc-gssd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:rpc-statd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:rpc-statd-notify",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:rpcbind",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:rpcbind.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:rsyslog",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sbd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sbd_remote",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:selinux-autorelabel",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:selinux-autorelabel-mark",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:serial-getty@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sshd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sshd-keygen@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sshd.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sshd@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sssd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sssd-autofs",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sssd-autofs.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sssd-kcm",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sssd-kcm.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sssd-nss",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sssd-nss.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sssd-pac",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sssd-pac.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sssd-pam",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sssd-pam-priv.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sssd-pam.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sssd-ssh",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sssd-ssh.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sssd-sudo",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sssd-sudo.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sys-fs-fuse-connections.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sys-kernel-config.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:sys-kernel-debug.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:syslog",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:syslog.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:system-update-cleanup",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-ask-password-console",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-ask-password-console.path",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-ask-password-plymouth",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-ask-password-plymouth.path",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-ask-password-wall",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-ask-password-wall.path",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-backlight@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-binfmt",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-coredump.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-coredump@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-exit",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-firstboot",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-fsck-root",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-fsck@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-halt",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-hibernate",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-hibernate-resume@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-hostnamed",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-hwdb-update",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-hybrid-sleep",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-initctl",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-initctl.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-journal-catalog-update",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-journal-flush",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-journald",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-journald-audit.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-journald-dev-log.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-journald.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-kexec",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-localed",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-logind",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-machine-id-commit",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-modules-load",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-portabled",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-poweroff",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-quotacheck",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-random-seed",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-reboot",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-remount-fs",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-resolved",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-rfkill",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-rfkill.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-suspend",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-suspend-then-hibernate",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-sysctl",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-sysusers",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-timedated",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-tmpfiles-clean",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-tmpfiles-clean.timer",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-tmpfiles-setup",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-tmpfiles-setup-dev",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-udev-settle",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-udev-trigger",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-udevd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-udevd-control.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-udevd-kernel.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-update-done",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-update-utmp",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-update-utmp-runlevel",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-user-sessions",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-vconsole-setup",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:systemd-volatile-root",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:tcsd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:teamd@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:timedatex",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:tmp.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:tuned",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:unbound-anchor",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:unbound-anchor.timer",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:user-runtime-dir@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:user@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "service:var-lib-nfs-rpc_pipefs.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:-.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:arp-ethers",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:auditd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:auth-rpcgss-module",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:autovt@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:blk-availability",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:boot.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:booth-arbitrator",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:booth@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:chrony-dnssrv@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:chrony-dnssrv@.timer",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:chrony-wait",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:chronyd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:console-getty",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:container-getty@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:corosync",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:corosync-notifyd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:cpupower",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:crm_mon",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:crond",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dbus",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dbus-org.freedesktop.hostname1",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dbus-org.freedesktop.locale1",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dbus-org.freedesktop.login1",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dbus-org.freedesktop.nm-dispatcher",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dbus-org.freedesktop.portable1",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dbus-org.freedesktop.timedate1",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dbus.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:debug-shell",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dev-hugepages.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dev-mqueue.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dm-event",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dm-event.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dnf-makecache",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dnf-makecache.timer",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dracut-cmdline",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dracut-initqueue",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dracut-mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dracut-pre-mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dracut-pre-pivot",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dracut-pre-trigger",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dracut-pre-udev",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:dracut-shutdown",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:ebtables",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:emergency",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:firewalld",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:fstrim",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:fstrim.timer",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:getty@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:grub-boot-indeterminate",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:gssproxy",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:halt-local",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:import-state",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:initrd-cleanup",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:initrd-parse-etc",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:initrd-switch-root",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:initrd-udevadm-cleanup-db",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:iprdump",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:iprinit",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:iprupdate",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:irqbalance",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:kdump",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:kmod-static-nodes",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:ldconfig",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:loadmodules",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:lvm2-lvmpolld",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:lvm2-lvmpolld.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:lvm2-monitor",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:lvm2-pvscan@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:man-db-cache-update",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:messagebus",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:microcode",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:multipathd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:multipathd.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:NetworkManager",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:NetworkManager-dispatcher",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:NetworkManager-wait-online",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:nfs-blkmap",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:nfs-convert",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:nfs-idmapd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:nfs-mountd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:nfs-server",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:nfs-utils",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:nfsdcld",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:nftables",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:nis-domainname",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:oddjobd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:pacemaker",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:pcsd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:pcsd-ruby",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:plymouth-halt",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:plymouth-kexec",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:plymouth-poweroff",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:plymouth-quit",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:plymouth-quit-wait",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:plymouth-read-write",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:plymouth-reboot",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:plymouth-start",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:plymouth-switch-root",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:plymouth-switch-root-initramfs",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:polkit",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:proc-fs-nfsd.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:proc-sys-fs-binfmt_misc.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:qemu-guest-agent",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:quotaon",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:rc-local",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:rdisc",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:rescue",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:rhsm",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:rhsm-facts",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:rhsmcertd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:rngd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:rngd-wake-threshold",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:rpc-gssd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:rpc-statd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:rpc-statd-notify",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:rpcbind",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:rpcbind.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:rsyslog",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sbd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sbd_remote",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:selinux-autorelabel",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:selinux-autorelabel-mark",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:serial-getty@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sshd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sshd-keygen@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sshd.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sshd@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sssd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sssd-autofs",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sssd-autofs.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sssd-kcm",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sssd-kcm.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sssd-nss",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sssd-nss.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sssd-pac",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sssd-pac.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sssd-pam",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sssd-pam-priv.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sssd-pam.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sssd-ssh",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sssd-ssh.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sssd-sudo",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sssd-sudo.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sys-fs-fuse-connections.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sys-kernel-config.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:sys-kernel-debug.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:syslog",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:syslog.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:system-update-cleanup",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-ask-password-console",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-ask-password-console.path",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-ask-password-plymouth",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-ask-password-plymouth.path",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-ask-password-wall",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-ask-password-wall.path",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-backlight@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-binfmt",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-coredump.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-coredump@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-exit",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-firstboot",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-fsck-root",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-fsck@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-halt",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-hibernate",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-hibernate-resume@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-hostnamed",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-hwdb-update",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-hybrid-sleep",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-initctl",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-initctl.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-journal-catalog-update",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-journal-flush",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-journald",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-journald-audit.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-journald-dev-log.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-journald.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-kexec",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-localed",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-logind",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-machine-id-commit",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-modules-load",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-portabled",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-poweroff",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-quotacheck",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-random-seed",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-reboot",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-remount-fs",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-resolved",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-rfkill",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-rfkill.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-suspend",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-suspend-then-hibernate",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-sysctl",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-sysusers",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-timedated",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-tmpfiles-clean",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-tmpfiles-clean.timer",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-tmpfiles-setup",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-tmpfiles-setup-dev",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-udev-settle",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-udev-trigger",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-udevd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-udevd-control.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-udevd-kernel.socket",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-update-done",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-update-utmp",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-update-utmp-runlevel",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-user-sessions",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-vconsole-setup",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:systemd-volatile-root",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:tcsd",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:teamd@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:timedatex",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:tmp.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:tuned",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:unbound-anchor",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:unbound-anchor.timer",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:user-runtime-dir@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:user@",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
  {
    name: "systemd:var-lib-nfs-rpc_pipefs.mount",
    shortdesc: "",
    longdesc: "",
    parameters: [],
    actions: [],
  },
];
