import * as intercept from "./interception";
import * as route from "./routes";
import * as shortcuts from "./shortcuts";
import {location} from "./backendAddress";

export {intercept, route, location, shortcuts};
